# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmPricingPlan(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        '_class': 'str',
        'edges': 'OrmPricingPlanEdges',
        'id': 'int',
        'name': 'str',
        'stripe_price_id': 'str',
        'stripe_product_id': 'str',
        'type': 'str'
    }

    attribute_map = {
        '_class': 'class',
        'edges': 'edges',
        'id': 'id',
        'name': 'name',
        'stripe_price_id': 'stripe_price_id',
        'stripe_product_id': 'stripe_product_id',
        'type': 'type'
    }

    def __init__(self, _class=None, edges=None, id=None, name=None, stripe_price_id=None, stripe_product_id=None, type=None, local_vars_configuration=None):  # noqa: E501
        """OrmPricingPlan - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self.__class = None
        self._edges = None
        self._id = None
        self._name = None
        self._stripe_price_id = None
        self._stripe_product_id = None
        self._type = None
        self.discriminator = None

        if _class is not None:
            self._class = _class
        if edges is not None:
            self.edges = edges
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        self.stripe_price_id = stripe_price_id
        self.stripe_product_id = stripe_product_id
        if type is not None:
            self.type = type

    @property
    def _class(self):
        """Gets the _class of this OrmPricingPlan.  # noqa: E501


        :return: The _class of this OrmPricingPlan.  # noqa: E501
        :rtype: str
        """
        return self.__class

    @_class.setter
    def _class(self, _class):
        """Sets the _class of this OrmPricingPlan.


        :param _class: The _class of this OrmPricingPlan.  # noqa: E501
        :type _class: str
        """

        self.__class = _class

    @property
    def edges(self):
        """Gets the edges of this OrmPricingPlan.  # noqa: E501


        :return: The edges of this OrmPricingPlan.  # noqa: E501
        :rtype: OrmPricingPlanEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this OrmPricingPlan.


        :param edges: The edges of this OrmPricingPlan.  # noqa: E501
        :type edges: OrmPricingPlanEdges
        """

        self._edges = edges

    @property
    def id(self):
        """Gets the id of this OrmPricingPlan.  # noqa: E501


        :return: The id of this OrmPricingPlan.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrmPricingPlan.


        :param id: The id of this OrmPricingPlan.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this OrmPricingPlan.  # noqa: E501


        :return: The name of this OrmPricingPlan.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OrmPricingPlan.


        :param name: The name of this OrmPricingPlan.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def stripe_price_id(self):
        """Gets the stripe_price_id of this OrmPricingPlan.  # noqa: E501


        :return: The stripe_price_id of this OrmPricingPlan.  # noqa: E501
        :rtype: str
        """
        return self._stripe_price_id

    @stripe_price_id.setter
    def stripe_price_id(self, stripe_price_id):
        """Sets the stripe_price_id of this OrmPricingPlan.


        :param stripe_price_id: The stripe_price_id of this OrmPricingPlan.  # noqa: E501
        :type stripe_price_id: str
        """

        self._stripe_price_id = stripe_price_id

    @property
    def stripe_product_id(self):
        """Gets the stripe_product_id of this OrmPricingPlan.  # noqa: E501


        :return: The stripe_product_id of this OrmPricingPlan.  # noqa: E501
        :rtype: str
        """
        return self._stripe_product_id

    @stripe_product_id.setter
    def stripe_product_id(self, stripe_product_id):
        """Sets the stripe_product_id of this OrmPricingPlan.


        :param stripe_product_id: The stripe_product_id of this OrmPricingPlan.  # noqa: E501
        :type stripe_product_id: str
        """

        self._stripe_product_id = stripe_product_id

    @property
    def type(self):
        """Gets the type of this OrmPricingPlan.  # noqa: E501


        :return: The type of this OrmPricingPlan.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this OrmPricingPlan.


        :param type: The type of this OrmPricingPlan.  # noqa: E501
        :type type: str
        """

        self._type = type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmPricingPlan):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmPricingPlan):
            return True

        return self.to_dict() != other.to_dict()
