# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseVolumeSourceEntity(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'artifact': 'ResponseArtifact',
        'cifs': 'V1CIFSMount',
        'csi': 'V1CSIMount',
        'dataset': 'ResponseDatasetInfo',
        'entity_not_found': 'bool',
        'git': 'V1GitReference',
        'googledisk': 'V1GoogleDiskMount',
        'gs': 'V1GSReference',
        'hostpath': 'V1HostPathMount',
        'model': 'ResponseModelCandidateInfo',
        'nfs': 'V1NFSMount',
        's3': 'V1S3Reference',
        'source_entity_type': 'str'
    }

    attribute_map = {
        'artifact': 'artifact',
        'cifs': 'cifs',
        'csi': 'csi',
        'dataset': 'dataset',
        'entity_not_found': 'entity_not_found',
        'git': 'git',
        'googledisk': 'googledisk',
        'gs': 'gs',
        'hostpath': 'hostpath',
        'model': 'model',
        'nfs': 'nfs',
        's3': 's3',
        'source_entity_type': 'source_entity_type'
    }

    def __init__(self, artifact=None, cifs=None, csi=None, dataset=None, entity_not_found=None, git=None, googledisk=None, gs=None, hostpath=None, model=None, nfs=None, s3=None, source_entity_type=None, local_vars_configuration=None):  # noqa: E501
        """ResponseVolumeSourceEntity - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._artifact = None
        self._cifs = None
        self._csi = None
        self._dataset = None
        self._entity_not_found = None
        self._git = None
        self._googledisk = None
        self._gs = None
        self._hostpath = None
        self._model = None
        self._nfs = None
        self._s3 = None
        self._source_entity_type = None
        self.discriminator = None

        if artifact is not None:
            self.artifact = artifact
        if cifs is not None:
            self.cifs = cifs
        if csi is not None:
            self.csi = csi
        if dataset is not None:
            self.dataset = dataset
        if entity_not_found is not None:
            self.entity_not_found = entity_not_found
        if git is not None:
            self.git = git
        if googledisk is not None:
            self.googledisk = googledisk
        if gs is not None:
            self.gs = gs
        if hostpath is not None:
            self.hostpath = hostpath
        if model is not None:
            self.model = model
        if nfs is not None:
            self.nfs = nfs
        if s3 is not None:
            self.s3 = s3
        if source_entity_type is not None:
            self.source_entity_type = source_entity_type

    @property
    def artifact(self):
        """Gets the artifact of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The artifact of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: ResponseArtifact
        """
        return self._artifact

    @artifact.setter
    def artifact(self, artifact):
        """Sets the artifact of this ResponseVolumeSourceEntity.


        :param artifact: The artifact of this ResponseVolumeSourceEntity.  # noqa: E501
        :type artifact: ResponseArtifact
        """

        self._artifact = artifact

    @property
    def cifs(self):
        """Gets the cifs of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The cifs of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: V1CIFSMount
        """
        return self._cifs

    @cifs.setter
    def cifs(self, cifs):
        """Sets the cifs of this ResponseVolumeSourceEntity.


        :param cifs: The cifs of this ResponseVolumeSourceEntity.  # noqa: E501
        :type cifs: V1CIFSMount
        """

        self._cifs = cifs

    @property
    def csi(self):
        """Gets the csi of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The csi of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: V1CSIMount
        """
        return self._csi

    @csi.setter
    def csi(self, csi):
        """Sets the csi of this ResponseVolumeSourceEntity.


        :param csi: The csi of this ResponseVolumeSourceEntity.  # noqa: E501
        :type csi: V1CSIMount
        """

        self._csi = csi

    @property
    def dataset(self):
        """Gets the dataset of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The dataset of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: ResponseDatasetInfo
        """
        return self._dataset

    @dataset.setter
    def dataset(self, dataset):
        """Sets the dataset of this ResponseVolumeSourceEntity.


        :param dataset: The dataset of this ResponseVolumeSourceEntity.  # noqa: E501
        :type dataset: ResponseDatasetInfo
        """

        self._dataset = dataset

    @property
    def entity_not_found(self):
        """Gets the entity_not_found of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The entity_not_found of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: bool
        """
        return self._entity_not_found

    @entity_not_found.setter
    def entity_not_found(self, entity_not_found):
        """Sets the entity_not_found of this ResponseVolumeSourceEntity.


        :param entity_not_found: The entity_not_found of this ResponseVolumeSourceEntity.  # noqa: E501
        :type entity_not_found: bool
        """

        self._entity_not_found = entity_not_found

    @property
    def git(self):
        """Gets the git of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The git of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: V1GitReference
        """
        return self._git

    @git.setter
    def git(self, git):
        """Sets the git of this ResponseVolumeSourceEntity.


        :param git: The git of this ResponseVolumeSourceEntity.  # noqa: E501
        :type git: V1GitReference
        """

        self._git = git

    @property
    def googledisk(self):
        """Gets the googledisk of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The googledisk of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: V1GoogleDiskMount
        """
        return self._googledisk

    @googledisk.setter
    def googledisk(self, googledisk):
        """Sets the googledisk of this ResponseVolumeSourceEntity.


        :param googledisk: The googledisk of this ResponseVolumeSourceEntity.  # noqa: E501
        :type googledisk: V1GoogleDiskMount
        """

        self._googledisk = googledisk

    @property
    def gs(self):
        """Gets the gs of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The gs of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: V1GSReference
        """
        return self._gs

    @gs.setter
    def gs(self, gs):
        """Sets the gs of this ResponseVolumeSourceEntity.


        :param gs: The gs of this ResponseVolumeSourceEntity.  # noqa: E501
        :type gs: V1GSReference
        """

        self._gs = gs

    @property
    def hostpath(self):
        """Gets the hostpath of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The hostpath of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: V1HostPathMount
        """
        return self._hostpath

    @hostpath.setter
    def hostpath(self, hostpath):
        """Sets the hostpath of this ResponseVolumeSourceEntity.


        :param hostpath: The hostpath of this ResponseVolumeSourceEntity.  # noqa: E501
        :type hostpath: V1HostPathMount
        """

        self._hostpath = hostpath

    @property
    def model(self):
        """Gets the model of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The model of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: ResponseModelCandidateInfo
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this ResponseVolumeSourceEntity.


        :param model: The model of this ResponseVolumeSourceEntity.  # noqa: E501
        :type model: ResponseModelCandidateInfo
        """

        self._model = model

    @property
    def nfs(self):
        """Gets the nfs of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The nfs of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: V1NFSMount
        """
        return self._nfs

    @nfs.setter
    def nfs(self, nfs):
        """Sets the nfs of this ResponseVolumeSourceEntity.


        :param nfs: The nfs of this ResponseVolumeSourceEntity.  # noqa: E501
        :type nfs: V1NFSMount
        """

        self._nfs = nfs

    @property
    def s3(self):
        """Gets the s3 of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The s3 of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: V1S3Reference
        """
        return self._s3

    @s3.setter
    def s3(self, s3):
        """Sets the s3 of this ResponseVolumeSourceEntity.


        :param s3: The s3 of this ResponseVolumeSourceEntity.  # noqa: E501
        :type s3: V1S3Reference
        """

        self._s3 = s3

    @property
    def source_entity_type(self):
        """Gets the source_entity_type of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The source_entity_type of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: str
        """
        return self._source_entity_type

    @source_entity_type.setter
    def source_entity_type(self, source_entity_type):
        """Sets the source_entity_type of this ResponseVolumeSourceEntity.


        :param source_entity_type: The source_entity_type of this ResponseVolumeSourceEntity.  # noqa: E501
        :type source_entity_type: str
        """
        allowed_values = ["dataset", "model", "artifact", "git", "s3", "gs", "hostpath", "nfs", "cifs", "googledisk", "csi", "unknown"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and source_entity_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `source_entity_type` ({0}), must be one of {1}"  # noqa: E501
                .format(source_entity_type, allowed_values)
            )

        self._source_entity_type = source_entity_type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseVolumeSourceEntity):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseVolumeSourceEntity):
            return True

        return self.to_dict() != other.to_dict()
